# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import StrictInt, constr, validator


from lidarr.api_client import ApiClient
from lidarr.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class MediaCoverApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_media_cover_albumalbum_id_by_filename(self, album_id : StrictInt, filename : constr(strict=True), **kwargs) -> None:  # noqa: E501
        """get_media_cover_albumalbum_id_by_filename  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_media_cover_albumalbum_id_by_filename(album_id, filename, async_req=True)
        >>> result = thread.get()

        :param album_id: (required)
        :type album_id: int
        :param filename: (required)
        :type filename: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.get_media_cover_albumalbum_id_by_filename_with_http_info(album_id, filename, **kwargs)  # noqa: E501

    @validate_arguments
    def get_media_cover_albumalbum_id_by_filename_with_http_info(self, album_id : StrictInt, filename : constr(strict=True), **kwargs):  # noqa: E501
        """get_media_cover_albumalbum_id_by_filename  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_media_cover_albumalbum_id_by_filename_with_http_info(album_id, filename, async_req=True)
        >>> result = thread.get()

        :param album_id: (required)
        :type album_id: int
        :param filename: (required)
        :type filename: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'album_id',
            'filename'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_media_cover_albumalbum_id_by_filename" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['album_id']:
            _path_params['albumId'] = _params['album_id']
        if _params['filename']:
            _path_params['filename'] = _params['filename']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # authentication setting
        _auth_settings = ['apikey', 'X-Api-Key']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/v1/mediacover/album/{albumId}/{filename}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_media_cover_artistartist_id_by_filename(self, artist_id : StrictInt, filename : constr(strict=True), **kwargs) -> None:  # noqa: E501
        """get_media_cover_artistartist_id_by_filename  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_media_cover_artistartist_id_by_filename(artist_id, filename, async_req=True)
        >>> result = thread.get()

        :param artist_id: (required)
        :type artist_id: int
        :param filename: (required)
        :type filename: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.get_media_cover_artistartist_id_by_filename_with_http_info(artist_id, filename, **kwargs)  # noqa: E501

    @validate_arguments
    def get_media_cover_artistartist_id_by_filename_with_http_info(self, artist_id : StrictInt, filename : constr(strict=True), **kwargs):  # noqa: E501
        """get_media_cover_artistartist_id_by_filename  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_media_cover_artistartist_id_by_filename_with_http_info(artist_id, filename, async_req=True)
        >>> result = thread.get()

        :param artist_id: (required)
        :type artist_id: int
        :param filename: (required)
        :type filename: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'artist_id',
            'filename'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_media_cover_artistartist_id_by_filename" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['artist_id']:
            _path_params['artistId'] = _params['artist_id']
        if _params['filename']:
            _path_params['filename'] = _params['filename']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # authentication setting
        _auth_settings = ['apikey', 'X-Api-Key']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/v1/mediacover/artist/{artistId}/{filename}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from lidarr.models.add_album_options import AddAlbumOptions
from lidarr.models.artist_metadata_lazy_loaded import ArtistMetadataLazyLoaded
from lidarr.models.links import Links
from lidarr.models.media_cover import MediaCover
from lidarr.models.ratings import Ratings
from lidarr.models.secondary_album_type import SecondaryAlbumType

class Album(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    artist_metadata_id: Optional[int]
    foreign_album_id: Optional[str]
    old_foreign_album_ids: Optional[List]
    title: Optional[str]
    overview: Optional[str]
    disambiguation: Optional[str]
    release_date: Optional[datetime]
    images: Optional[List]
    links: Optional[List]
    genres: Optional[List]
    album_type: Optional[str]
    secondary_types: Optional[List]
    ratings: Optional[Ratings]
    clean_title: Optional[str]
    profile_id: Optional[int]
    monitored: Optional[bool]
    any_release_ok: Optional[bool]
    last_info_sync: Optional[datetime]
    added: Optional[datetime]
    add_options: Optional[AddAlbumOptions]
    artist_metadata: Optional[ArtistMetadataLazyLoaded]
    album_releases: Optional[AlbumReleaseListLazyLoaded]
    artist: Optional[ArtistLazyLoaded]
    __properties = ["id", "artistMetadataId", "foreignAlbumId", "oldForeignAlbumIds", "title", "overview", "disambiguation", "releaseDate", "images", "links", "genres", "albumType", "secondaryTypes", "ratings", "cleanTitle", "profileId", "monitored", "anyReleaseOk", "lastInfoSync", "added", "addOptions", "artistMetadata", "albumReleases", "artist"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Album:
        """Create an instance of Album from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item in self.images:
                if _item:
                    _items.append(_item.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item in self.links:
                if _item:
                    _items.append(_item.to_dict())
            _dict['links'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in secondary_types (list)
        _items = []
        if self.secondary_types:
            for _item in self.secondary_types:
                if _item:
                    _items.append(_item.to_dict())
            _dict['secondaryTypes'] = _items
        # override the default output from pydantic by calling `to_dict()` of ratings
        if self.ratings:
            _dict['ratings'] = self.ratings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of add_options
        if self.add_options:
            _dict['addOptions'] = self.add_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of artist_metadata
        if self.artist_metadata:
            _dict['artistMetadata'] = self.artist_metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of album_releases
        if self.album_releases:
            _dict['albumReleases'] = self.album_releases.to_dict()
        # override the default output from pydantic by calling `to_dict()` of artist
        if self.artist:
            _dict['artist'] = self.artist.to_dict()
        # set to None if foreign_album_id (nullable) is None
        if self.foreign_album_id is None:
            _dict['foreignAlbumId'] = None

        # set to None if old_foreign_album_ids (nullable) is None
        if self.old_foreign_album_ids is None:
            _dict['oldForeignAlbumIds'] = None

        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if overview (nullable) is None
        if self.overview is None:
            _dict['overview'] = None

        # set to None if disambiguation (nullable) is None
        if self.disambiguation is None:
            _dict['disambiguation'] = None

        # set to None if release_date (nullable) is None
        if self.release_date is None:
            _dict['releaseDate'] = None

        # set to None if images (nullable) is None
        if self.images is None:
            _dict['images'] = None

        # set to None if links (nullable) is None
        if self.links is None:
            _dict['links'] = None

        # set to None if genres (nullable) is None
        if self.genres is None:
            _dict['genres'] = None

        # set to None if album_type (nullable) is None
        if self.album_type is None:
            _dict['albumType'] = None

        # set to None if secondary_types (nullable) is None
        if self.secondary_types is None:
            _dict['secondaryTypes'] = None

        # set to None if clean_title (nullable) is None
        if self.clean_title is None:
            _dict['cleanTitle'] = None

        # set to None if last_info_sync (nullable) is None
        if self.last_info_sync is None:
            _dict['lastInfoSync'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Album:
        """Create an instance of Album from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Album.parse_obj(obj)

        _obj = Album.parse_obj({
            "id": obj.get("id"),
            "artist_metadata_id": obj.get("artistMetadataId"),
            "foreign_album_id": obj.get("foreignAlbumId"),
            "old_foreign_album_ids": obj.get("oldForeignAlbumIds"),
            "title": obj.get("title"),
            "overview": obj.get("overview"),
            "disambiguation": obj.get("disambiguation"),
            "release_date": obj.get("releaseDate"),
            "images": [MediaCover.from_dict(_item) for _item in obj.get("images")] if obj.get("images") is not None else None,
            "links": [Links.from_dict(_item) for _item in obj.get("links")] if obj.get("links") is not None else None,
            "genres": obj.get("genres"),
            "album_type": obj.get("albumType"),
            "secondary_types": [SecondaryAlbumType.from_dict(_item) for _item in obj.get("secondaryTypes")] if obj.get("secondaryTypes") is not None else None,
            "ratings": Ratings.from_dict(obj.get("ratings")) if obj.get("ratings") is not None else None,
            "clean_title": obj.get("cleanTitle"),
            "profile_id": obj.get("profileId"),
            "monitored": obj.get("monitored"),
            "any_release_ok": obj.get("anyReleaseOk"),
            "last_info_sync": obj.get("lastInfoSync"),
            "added": obj.get("added"),
            "add_options": AddAlbumOptions.from_dict(obj.get("addOptions")) if obj.get("addOptions") is not None else None,
            "artist_metadata": ArtistMetadataLazyLoaded.from_dict(obj.get("artistMetadata")) if obj.get("artistMetadata") is not None else None,
            "album_releases": AlbumReleaseListLazyLoaded.from_dict(obj.get("albumReleases")) if obj.get("albumReleases") is not None else None,
            "artist": ArtistLazyLoaded.from_dict(obj.get("artist")) if obj.get("artist") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from lidarr.models.tag_difference import TagDifference

class RetagTrackResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    artist_id: Optional[int]
    album_id: Optional[int]
    track_numbers: Optional[List]
    track_file_id: Optional[int]
    path: Optional[str]
    changes: Optional[List]
    __properties = ["id", "artistId", "albumId", "trackNumbers", "trackFileId", "path", "changes"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RetagTrackResource:
        """Create an instance of RetagTrackResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in changes (list)
        _items = []
        if self.changes:
            for _item in self.changes:
                if _item:
                    _items.append(_item.to_dict())
            _dict['changes'] = _items
        # set to None if track_numbers (nullable) is None
        if self.track_numbers is None:
            _dict['trackNumbers'] = None

        # set to None if path (nullable) is None
        if self.path is None:
            _dict['path'] = None

        # set to None if changes (nullable) is None
        if self.changes is None:
            _dict['changes'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RetagTrackResource:
        """Create an instance of RetagTrackResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return RetagTrackResource.parse_obj(obj)

        _obj = RetagTrackResource.parse_obj({
            "id": obj.get("id"),
            "artist_id": obj.get("artistId"),
            "album_id": obj.get("albumId"),
            "track_numbers": obj.get("trackNumbers"),
            "track_file_id": obj.get("trackFileId"),
            "path": obj.get("path"),
            "changes": [TagDifference.from_dict(_item) for _item in obj.get("changes")] if obj.get("changes") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from lidarr.models.add_album_options import AddAlbumOptions
from lidarr.models.album_release_resource import AlbumReleaseResource
from lidarr.models.album_statistics_resource import AlbumStatisticsResource
from lidarr.models.artist_resource import ArtistResource
from lidarr.models.links import Links
from lidarr.models.media_cover import MediaCover
from lidarr.models.medium_resource import MediumResource
from lidarr.models.ratings import Ratings

class AlbumResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    title: Optional[str]
    disambiguation: Optional[str]
    overview: Optional[str]
    artist_id: Optional[int]
    foreign_album_id: Optional[str]
    monitored: Optional[bool]
    any_release_ok: Optional[bool]
    profile_id: Optional[int]
    duration: Optional[int]
    album_type: Optional[str]
    secondary_types: Optional[List]
    medium_count: Optional[int]
    ratings: Optional[Ratings]
    release_date: Optional[datetime]
    releases: Optional[List]
    genres: Optional[List]
    media: Optional[List]
    artist: Optional[ArtistResource]
    images: Optional[List]
    links: Optional[List]
    statistics: Optional[AlbumStatisticsResource]
    add_options: Optional[AddAlbumOptions]
    remote_cover: Optional[str]
    grabbed: Optional[bool]
    __properties = ["id", "title", "disambiguation", "overview", "artistId", "foreignAlbumId", "monitored", "anyReleaseOk", "profileId", "duration", "albumType", "secondaryTypes", "mediumCount", "ratings", "releaseDate", "releases", "genres", "media", "artist", "images", "links", "statistics", "addOptions", "remoteCover", "grabbed"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AlbumResource:
        """Create an instance of AlbumResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "medium_count",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of ratings
        if self.ratings:
            _dict['ratings'] = self.ratings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in releases (list)
        _items = []
        if self.releases:
            for _item in self.releases:
                if _item:
                    _items.append(_item.to_dict())
            _dict['releases'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in media (list)
        _items = []
        if self.media:
            for _item in self.media:
                if _item:
                    _items.append(_item.to_dict())
            _dict['media'] = _items
        # override the default output from pydantic by calling `to_dict()` of artist
        if self.artist:
            _dict['artist'] = self.artist.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item in self.images:
                if _item:
                    _items.append(_item.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item in self.links:
                if _item:
                    _items.append(_item.to_dict())
            _dict['links'] = _items
        # override the default output from pydantic by calling `to_dict()` of statistics
        if self.statistics:
            _dict['statistics'] = self.statistics.to_dict()
        # override the default output from pydantic by calling `to_dict()` of add_options
        if self.add_options:
            _dict['addOptions'] = self.add_options.to_dict()
        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if disambiguation (nullable) is None
        if self.disambiguation is None:
            _dict['disambiguation'] = None

        # set to None if overview (nullable) is None
        if self.overview is None:
            _dict['overview'] = None

        # set to None if foreign_album_id (nullable) is None
        if self.foreign_album_id is None:
            _dict['foreignAlbumId'] = None

        # set to None if album_type (nullable) is None
        if self.album_type is None:
            _dict['albumType'] = None

        # set to None if secondary_types (nullable) is None
        if self.secondary_types is None:
            _dict['secondaryTypes'] = None

        # set to None if release_date (nullable) is None
        if self.release_date is None:
            _dict['releaseDate'] = None

        # set to None if releases (nullable) is None
        if self.releases is None:
            _dict['releases'] = None

        # set to None if genres (nullable) is None
        if self.genres is None:
            _dict['genres'] = None

        # set to None if media (nullable) is None
        if self.media is None:
            _dict['media'] = None

        # set to None if images (nullable) is None
        if self.images is None:
            _dict['images'] = None

        # set to None if links (nullable) is None
        if self.links is None:
            _dict['links'] = None

        # set to None if remote_cover (nullable) is None
        if self.remote_cover is None:
            _dict['remoteCover'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AlbumResource:
        """Create an instance of AlbumResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AlbumResource.parse_obj(obj)

        _obj = AlbumResource.parse_obj({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "disambiguation": obj.get("disambiguation"),
            "overview": obj.get("overview"),
            "artist_id": obj.get("artistId"),
            "foreign_album_id": obj.get("foreignAlbumId"),
            "monitored": obj.get("monitored"),
            "any_release_ok": obj.get("anyReleaseOk"),
            "profile_id": obj.get("profileId"),
            "duration": obj.get("duration"),
            "album_type": obj.get("albumType"),
            "secondary_types": obj.get("secondaryTypes"),
            "medium_count": obj.get("mediumCount"),
            "ratings": Ratings.from_dict(obj.get("ratings")) if obj.get("ratings") is not None else None,
            "release_date": obj.get("releaseDate"),
            "releases": [AlbumReleaseResource.from_dict(_item) for _item in obj.get("releases")] if obj.get("releases") is not None else None,
            "genres": obj.get("genres"),
            "media": [MediumResource.from_dict(_item) for _item in obj.get("media")] if obj.get("media") is not None else None,
            "artist": ArtistResource.from_dict(obj.get("artist")) if obj.get("artist") is not None else None,
            "images": [MediaCover.from_dict(_item) for _item in obj.get("images")] if obj.get("images") is not None else None,
            "links": [Links.from_dict(_item) for _item in obj.get("links")] if obj.get("links") is not None else None,
            "statistics": AlbumStatisticsResource.from_dict(obj.get("statistics")) if obj.get("statistics") is not None else None,
            "add_options": AddAlbumOptions.from_dict(obj.get("addOptions")) if obj.get("addOptions") is not None else None,
            "remote_cover": obj.get("remoteCover"),
            "grabbed": obj.get("grabbed")
        })
        return _obj




# coding: utf-8

# flake8: noqa

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# x-release-please-start-version
__version__ = "0.3.1"
# x-release-please-end

# import apis into sdk package
from lidarr.api.album_api import AlbumApi
from lidarr.api.album_lookup_api import AlbumLookupApi
from lidarr.api.album_studio_api import AlbumStudioApi
from lidarr.api.api_info_api import ApiInfoApi
from lidarr.api.artist_api import ArtistApi
from lidarr.api.artist_editor_api import ArtistEditorApi
from lidarr.api.artist_lookup_api import ArtistLookupApi
from lidarr.api.authentication_api import AuthenticationApi
from lidarr.api.backup_api import BackupApi
from lidarr.api.blocklist_api import BlocklistApi
from lidarr.api.calendar_api import CalendarApi
from lidarr.api.calendar_feed_api import CalendarFeedApi
from lidarr.api.command_api import CommandApi
from lidarr.api.custom_filter_api import CustomFilterApi
from lidarr.api.custom_format_api import CustomFormatApi
from lidarr.api.cutoff_api import CutoffApi
from lidarr.api.delay_profile_api import DelayProfileApi
from lidarr.api.disk_space_api import DiskSpaceApi
from lidarr.api.download_client_api import DownloadClientApi
from lidarr.api.download_client_config_api import DownloadClientConfigApi
from lidarr.api.file_system_api import FileSystemApi
from lidarr.api.health_api import HealthApi
from lidarr.api.history_api import HistoryApi
from lidarr.api.host_config_api import HostConfigApi
from lidarr.api.import_list_api import ImportListApi
from lidarr.api.import_list_exclusion_api import ImportListExclusionApi
from lidarr.api.indexer_api import IndexerApi
from lidarr.api.indexer_config_api import IndexerConfigApi
from lidarr.api.initialize_js_api import InitializeJsApi
from lidarr.api.language_api import LanguageApi
from lidarr.api.localization_api import LocalizationApi
from lidarr.api.log_api import LogApi
from lidarr.api.log_file_api import LogFileApi
from lidarr.api.manual_import_api import ManualImportApi
from lidarr.api.media_cover_api import MediaCoverApi
from lidarr.api.media_management_config_api import MediaManagementConfigApi
from lidarr.api.metadata_api import MetadataApi
from lidarr.api.metadata_profile_api import MetadataProfileApi
from lidarr.api.metadata_profile_schema_api import MetadataProfileSchemaApi
from lidarr.api.metadata_provider_config_api import MetadataProviderConfigApi
from lidarr.api.missing_api import MissingApi
from lidarr.api.naming_config_api import NamingConfigApi
from lidarr.api.notification_api import NotificationApi
from lidarr.api.parse_api import ParseApi
from lidarr.api.ping_api import PingApi
from lidarr.api.quality_definition_api import QualityDefinitionApi
from lidarr.api.quality_profile_api import QualityProfileApi
from lidarr.api.quality_profile_schema_api import QualityProfileSchemaApi
from lidarr.api.queue_api import QueueApi
from lidarr.api.queue_action_api import QueueActionApi
from lidarr.api.queue_details_api import QueueDetailsApi
from lidarr.api.queue_status_api import QueueStatusApi
from lidarr.api.release_api import ReleaseApi
from lidarr.api.release_profile_api import ReleaseProfileApi
from lidarr.api.release_push_api import ReleasePushApi
from lidarr.api.remote_path_mapping_api import RemotePathMappingApi
from lidarr.api.rename_track_api import RenameTrackApi
from lidarr.api.retag_track_api import RetagTrackApi
from lidarr.api.root_folder_api import RootFolderApi
from lidarr.api.search_api import SearchApi
from lidarr.api.static_resource_api import StaticResourceApi
from lidarr.api.system_api import SystemApi
from lidarr.api.tag_api import TagApi
from lidarr.api.tag_details_api import TagDetailsApi
from lidarr.api.task_api import TaskApi
from lidarr.api.track_api import TrackApi
from lidarr.api.track_file_api import TrackFileApi
from lidarr.api.ui_config_api import UiConfigApi
from lidarr.api.update_api import UpdateApi
from lidarr.api.update_log_file_api import UpdateLogFileApi

# import ApiClient
from lidarr.api_client import ApiClient
from lidarr.configuration import Configuration
from lidarr.exceptions import OpenApiException
from lidarr.exceptions import ApiTypeError
from lidarr.exceptions import ApiValueError
from lidarr.exceptions import ApiKeyError
from lidarr.exceptions import ApiAttributeError
from lidarr.exceptions import ApiException
# import models into sdk package
from lidarr.models.add_album_options import AddAlbumOptions
from lidarr.models.add_artist_options import AddArtistOptions
from lidarr.models.album import Album
from lidarr.models.album_add_type import AlbumAddType
from lidarr.models.album_lazy_loaded import AlbumLazyLoaded
from lidarr.models.album_list_lazy_loaded import AlbumListLazyLoaded
from lidarr.models.album_release import AlbumRelease
from lidarr.models.album_release_lazy_loaded import AlbumReleaseLazyLoaded
from lidarr.models.album_release_list_lazy_loaded import AlbumReleaseListLazyLoaded
from lidarr.models.album_release_resource import AlbumReleaseResource
from lidarr.models.album_resource import AlbumResource
from lidarr.models.album_resource_paging_resource import AlbumResourcePagingResource
from lidarr.models.album_statistics_resource import AlbumStatisticsResource
from lidarr.models.album_studio_artist_resource import AlbumStudioArtistResource
from lidarr.models.album_studio_resource import AlbumStudioResource
from lidarr.models.albums_monitored_resource import AlbumsMonitoredResource
from lidarr.models.allow_fingerprinting import AllowFingerprinting
from lidarr.models.apply_tags import ApplyTags
from lidarr.models.artist import Artist
from lidarr.models.artist_editor_resource import ArtistEditorResource
from lidarr.models.artist_lazy_loaded import ArtistLazyLoaded
from lidarr.models.artist_metadata import ArtistMetadata
from lidarr.models.artist_metadata_lazy_loaded import ArtistMetadataLazyLoaded
from lidarr.models.artist_resource import ArtistResource
from lidarr.models.artist_statistics_resource import ArtistStatisticsResource
from lidarr.models.artist_status_type import ArtistStatusType
from lidarr.models.artist_title_info import ArtistTitleInfo
from lidarr.models.authentication_type import AuthenticationType
from lidarr.models.backup_resource import BackupResource
from lidarr.models.backup_type import BackupType
from lidarr.models.blocklist_bulk_resource import BlocklistBulkResource
from lidarr.models.blocklist_resource import BlocklistResource
from lidarr.models.blocklist_resource_paging_resource import BlocklistResourcePagingResource
from lidarr.models.certificate_validation_type import CertificateValidationType
from lidarr.models.command import Command
from lidarr.models.command_priority import CommandPriority
from lidarr.models.command_resource import CommandResource
from lidarr.models.command_result import CommandResult
from lidarr.models.command_status import CommandStatus
from lidarr.models.command_trigger import CommandTrigger
from lidarr.models.custom_filter_resource import CustomFilterResource
from lidarr.models.custom_format import CustomFormat
from lidarr.models.custom_format_resource import CustomFormatResource
from lidarr.models.custom_format_specification_schema import CustomFormatSpecificationSchema
from lidarr.models.database_type import DatabaseType
from lidarr.models.delay_profile_resource import DelayProfileResource
from lidarr.models.disk_space_resource import DiskSpaceResource
from lidarr.models.download_client_bulk_resource import DownloadClientBulkResource
from lidarr.models.download_client_config_resource import DownloadClientConfigResource
from lidarr.models.download_client_resource import DownloadClientResource
from lidarr.models.download_protocol import DownloadProtocol
from lidarr.models.entity_history_event_type import EntityHistoryEventType
from lidarr.models.field import Field
from lidarr.models.file_date_type import FileDateType
from lidarr.models.health_check_result import HealthCheckResult
from lidarr.models.health_resource import HealthResource
from lidarr.models.history_resource import HistoryResource
from lidarr.models.history_resource_paging_resource import HistoryResourcePagingResource
from lidarr.models.host_config_resource import HostConfigResource
from lidarr.models.i_custom_format_specification import ICustomFormatSpecification
from lidarr.models.import_list_bulk_resource import ImportListBulkResource
from lidarr.models.import_list_exclusion_resource import ImportListExclusionResource
from lidarr.models.import_list_monitor_type import ImportListMonitorType
from lidarr.models.import_list_resource import ImportListResource
from lidarr.models.import_list_type import ImportListType
from lidarr.models.indexer_bulk_resource import IndexerBulkResource
from lidarr.models.indexer_config_resource import IndexerConfigResource
from lidarr.models.indexer_resource import IndexerResource
from lidarr.models.iso_country import IsoCountry
from lidarr.models.language_resource import LanguageResource
from lidarr.models.links import Links
from lidarr.models.localization_resource import LocalizationResource
from lidarr.models.log_file_resource import LogFileResource
from lidarr.models.log_resource import LogResource
from lidarr.models.log_resource_paging_resource import LogResourcePagingResource
from lidarr.models.manual_import_resource import ManualImportResource
from lidarr.models.manual_import_update_resource import ManualImportUpdateResource
from lidarr.models.media_cover import MediaCover
from lidarr.models.media_cover_types import MediaCoverTypes
from lidarr.models.media_info_model import MediaInfoModel
from lidarr.models.media_info_resource import MediaInfoResource
from lidarr.models.media_management_config_resource import MediaManagementConfigResource
from lidarr.models.medium import Medium
from lidarr.models.medium_resource import MediumResource
from lidarr.models.member import Member
from lidarr.models.metadata_profile import MetadataProfile
from lidarr.models.metadata_profile_lazy_loaded import MetadataProfileLazyLoaded
from lidarr.models.metadata_profile_resource import MetadataProfileResource
from lidarr.models.metadata_provider_config_resource import MetadataProviderConfigResource
from lidarr.models.metadata_resource import MetadataResource
from lidarr.models.monitor_types import MonitorTypes
from lidarr.models.monitoring_options import MonitoringOptions
from lidarr.models.naming_config_resource import NamingConfigResource
from lidarr.models.new_item_monitor_types import NewItemMonitorTypes
from lidarr.models.notification_resource import NotificationResource
from lidarr.models.paging_resource_filter import PagingResourceFilter
from lidarr.models.parse_resource import ParseResource
from lidarr.models.parsed_album_info import ParsedAlbumInfo
from lidarr.models.parsed_track_info import ParsedTrackInfo
from lidarr.models.ping_resource import PingResource
from lidarr.models.primary_album_type import PrimaryAlbumType
from lidarr.models.profile_format_item import ProfileFormatItem
from lidarr.models.profile_format_item_resource import ProfileFormatItemResource
from lidarr.models.profile_primary_album_type_item import ProfilePrimaryAlbumTypeItem
from lidarr.models.profile_primary_album_type_item_resource import ProfilePrimaryAlbumTypeItemResource
from lidarr.models.profile_release_status_item import ProfileReleaseStatusItem
from lidarr.models.profile_release_status_item_resource import ProfileReleaseStatusItemResource
from lidarr.models.profile_secondary_album_type_item import ProfileSecondaryAlbumTypeItem
from lidarr.models.profile_secondary_album_type_item_resource import ProfileSecondaryAlbumTypeItemResource
from lidarr.models.proper_download_types import ProperDownloadTypes
from lidarr.models.provider_message import ProviderMessage
from lidarr.models.provider_message_type import ProviderMessageType
from lidarr.models.proxy_type import ProxyType
from lidarr.models.quality import Quality
from lidarr.models.quality_definition_resource import QualityDefinitionResource
from lidarr.models.quality_model import QualityModel
from lidarr.models.quality_profile import QualityProfile
from lidarr.models.quality_profile_lazy_loaded import QualityProfileLazyLoaded
from lidarr.models.quality_profile_quality_item import QualityProfileQualityItem
from lidarr.models.quality_profile_quality_item_resource import QualityProfileQualityItemResource
from lidarr.models.quality_profile_resource import QualityProfileResource
from lidarr.models.queue_bulk_resource import QueueBulkResource
from lidarr.models.queue_resource import QueueResource
from lidarr.models.queue_resource_paging_resource import QueueResourcePagingResource
from lidarr.models.queue_status_resource import QueueStatusResource
from lidarr.models.ratings import Ratings
from lidarr.models.rejection import Rejection
from lidarr.models.rejection_type import RejectionType
from lidarr.models.release_profile_resource import ReleaseProfileResource
from lidarr.models.release_resource import ReleaseResource
from lidarr.models.release_status import ReleaseStatus
from lidarr.models.remote_path_mapping_resource import RemotePathMappingResource
from lidarr.models.rename_track_resource import RenameTrackResource
from lidarr.models.rescan_after_refresh_type import RescanAfterRefreshType
from lidarr.models.retag_track_resource import RetagTrackResource
from lidarr.models.revision import Revision
from lidarr.models.root_folder_resource import RootFolderResource
from lidarr.models.runtime_mode import RuntimeMode
from lidarr.models.secondary_album_type import SecondaryAlbumType
from lidarr.models.select_option import SelectOption
from lidarr.models.sort_direction import SortDirection
from lidarr.models.system_resource import SystemResource
from lidarr.models.tag_details_resource import TagDetailsResource
from lidarr.models.tag_difference import TagDifference
from lidarr.models.tag_resource import TagResource
from lidarr.models.task_resource import TaskResource
from lidarr.models.track import Track
from lidarr.models.track_file import TrackFile
from lidarr.models.track_file_lazy_loaded import TrackFileLazyLoaded
from lidarr.models.track_file_list_resource import TrackFileListResource
from lidarr.models.track_file_resource import TrackFileResource
from lidarr.models.track_list_lazy_loaded import TrackListLazyLoaded
from lidarr.models.track_resource import TrackResource
from lidarr.models.tracked_download_state import TrackedDownloadState
from lidarr.models.tracked_download_status import TrackedDownloadStatus
from lidarr.models.tracked_download_status_message import TrackedDownloadStatusMessage
from lidarr.models.ui_config_resource import UiConfigResource
from lidarr.models.update_changes import UpdateChanges
from lidarr.models.update_mechanism import UpdateMechanism
from lidarr.models.update_resource import UpdateResource
from lidarr.models.write_audio_tags_type import WriteAudioTagsType



# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from lidarr.models.artist_status_type import ArtistStatusType
from lidarr.models.links import Links
from lidarr.models.media_cover import MediaCover
from lidarr.models.member import Member
from lidarr.models.ratings import Ratings

class ArtistMetadata(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    foreign_artist_id: Optional[str]
    old_foreign_artist_ids: Optional[List]
    name: Optional[str]
    aliases: Optional[List]
    overview: Optional[str]
    disambiguation: Optional[str]
    type: Optional[str]
    status: Optional[ArtistStatusType]
    images: Optional[List]
    links: Optional[List]
    genres: Optional[List]
    ratings: Optional[Ratings]
    members: Optional[List]
    __properties = ["id", "foreignArtistId", "oldForeignArtistIds", "name", "aliases", "overview", "disambiguation", "type", "status", "images", "links", "genres", "ratings", "members"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ArtistMetadata:
        """Create an instance of ArtistMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item in self.images:
                if _item:
                    _items.append(_item.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item in self.links:
                if _item:
                    _items.append(_item.to_dict())
            _dict['links'] = _items
        # override the default output from pydantic by calling `to_dict()` of ratings
        if self.ratings:
            _dict['ratings'] = self.ratings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in members (list)
        _items = []
        if self.members:
            for _item in self.members:
                if _item:
                    _items.append(_item.to_dict())
            _dict['members'] = _items
        # set to None if foreign_artist_id (nullable) is None
        if self.foreign_artist_id is None:
            _dict['foreignArtistId'] = None

        # set to None if old_foreign_artist_ids (nullable) is None
        if self.old_foreign_artist_ids is None:
            _dict['oldForeignArtistIds'] = None

        # set to None if name (nullable) is None
        if self.name is None:
            _dict['name'] = None

        # set to None if aliases (nullable) is None
        if self.aliases is None:
            _dict['aliases'] = None

        # set to None if overview (nullable) is None
        if self.overview is None:
            _dict['overview'] = None

        # set to None if disambiguation (nullable) is None
        if self.disambiguation is None:
            _dict['disambiguation'] = None

        # set to None if type (nullable) is None
        if self.type is None:
            _dict['type'] = None

        # set to None if images (nullable) is None
        if self.images is None:
            _dict['images'] = None

        # set to None if links (nullable) is None
        if self.links is None:
            _dict['links'] = None

        # set to None if genres (nullable) is None
        if self.genres is None:
            _dict['genres'] = None

        # set to None if members (nullable) is None
        if self.members is None:
            _dict['members'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ArtistMetadata:
        """Create an instance of ArtistMetadata from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ArtistMetadata.parse_obj(obj)

        _obj = ArtistMetadata.parse_obj({
            "id": obj.get("id"),
            "foreign_artist_id": obj.get("foreignArtistId"),
            "old_foreign_artist_ids": obj.get("oldForeignArtistIds"),
            "name": obj.get("name"),
            "aliases": obj.get("aliases"),
            "overview": obj.get("overview"),
            "disambiguation": obj.get("disambiguation"),
            "type": obj.get("type"),
            "status": obj.get("status"),
            "images": [MediaCover.from_dict(_item) for _item in obj.get("images")] if obj.get("images") is not None else None,
            "links": [Links.from_dict(_item) for _item in obj.get("links")] if obj.get("links") is not None else None,
            "genres": obj.get("genres"),
            "ratings": Ratings.from_dict(obj.get("ratings")) if obj.get("ratings") is not None else None,
            "members": [Member.from_dict(_item) for _item in obj.get("members")] if obj.get("members") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from lidarr.models.medium_resource import MediumResource

class AlbumReleaseResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    album_id: Optional[int]
    foreign_release_id: Optional[str]
    title: Optional[str]
    status: Optional[str]
    duration: Optional[int]
    track_count: Optional[int]
    media: Optional[List]
    medium_count: Optional[int]
    disambiguation: Optional[str]
    country: Optional[List]
    label: Optional[List]
    format: Optional[str]
    monitored: Optional[bool]
    __properties = ["id", "albumId", "foreignReleaseId", "title", "status", "duration", "trackCount", "media", "mediumCount", "disambiguation", "country", "label", "format", "monitored"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AlbumReleaseResource:
        """Create an instance of AlbumReleaseResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "medium_count",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in media (list)
        _items = []
        if self.media:
            for _item in self.media:
                if _item:
                    _items.append(_item.to_dict())
            _dict['media'] = _items
        # set to None if foreign_release_id (nullable) is None
        if self.foreign_release_id is None:
            _dict['foreignReleaseId'] = None

        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if status (nullable) is None
        if self.status is None:
            _dict['status'] = None

        # set to None if media (nullable) is None
        if self.media is None:
            _dict['media'] = None

        # set to None if disambiguation (nullable) is None
        if self.disambiguation is None:
            _dict['disambiguation'] = None

        # set to None if country (nullable) is None
        if self.country is None:
            _dict['country'] = None

        # set to None if label (nullable) is None
        if self.label is None:
            _dict['label'] = None

        # set to None if format (nullable) is None
        if self.format is None:
            _dict['format'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AlbumReleaseResource:
        """Create an instance of AlbumReleaseResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AlbumReleaseResource.parse_obj(obj)

        _obj = AlbumReleaseResource.parse_obj({
            "id": obj.get("id"),
            "album_id": obj.get("albumId"),
            "foreign_release_id": obj.get("foreignReleaseId"),
            "title": obj.get("title"),
            "status": obj.get("status"),
            "duration": obj.get("duration"),
            "track_count": obj.get("trackCount"),
            "media": [MediumResource.from_dict(_item) for _item in obj.get("media")] if obj.get("media") is not None else None,
            "medium_count": obj.get("mediumCount"),
            "disambiguation": obj.get("disambiguation"),
            "country": obj.get("country"),
            "label": obj.get("label"),
            "format": obj.get("format"),
            "monitored": obj.get("monitored")
        })
        return _obj




# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from lidarr.models.profile_format_item_resource import ProfileFormatItemResource
from lidarr.models.quality_profile_quality_item_resource import QualityProfileQualityItemResource

class QualityProfileResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    name: Optional[str]
    upgrade_allowed: Optional[bool]
    cutoff: Optional[int]
    items: Optional[List]
    min_format_score: Optional[int]
    cutoff_format_score: Optional[int]
    format_items: Optional[List]
    __properties = ["id", "name", "upgradeAllowed", "cutoff", "items", "minFormatScore", "cutoffFormatScore", "formatItems"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> QualityProfileResource:
        """Create an instance of QualityProfileResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item in self.items:
                if _item:
                    _items.append(_item.to_dict())
            _dict['items'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in format_items (list)
        _items = []
        if self.format_items:
            for _item in self.format_items:
                if _item:
                    _items.append(_item.to_dict())
            _dict['formatItems'] = _items
        # set to None if name (nullable) is None
        if self.name is None:
            _dict['name'] = None

        # set to None if items (nullable) is None
        if self.items is None:
            _dict['items'] = None

        # set to None if format_items (nullable) is None
        if self.format_items is None:
            _dict['formatItems'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> QualityProfileResource:
        """Create an instance of QualityProfileResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return QualityProfileResource.parse_obj(obj)

        _obj = QualityProfileResource.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "upgrade_allowed": obj.get("upgradeAllowed"),
            "cutoff": obj.get("cutoff"),
            "items": [QualityProfileQualityItemResource.from_dict(_item) for _item in obj.get("items")] if obj.get("items") is not None else None,
            "min_format_score": obj.get("minFormatScore"),
            "cutoff_format_score": obj.get("cutoffFormatScore"),
            "format_items": [ProfileFormatItemResource.from_dict(_item) for _item in obj.get("formatItems")] if obj.get("formatItems") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from lidarr.models.artist_title_info import ArtistTitleInfo
from lidarr.models.iso_country import IsoCountry
from lidarr.models.media_info_model import MediaInfoModel
from lidarr.models.quality_model import QualityModel

class ParsedTrackInfo(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    title: Optional[str]
    clean_title: Optional[str]
    artist_title: Optional[str]
    album_title: Optional[str]
    artist_title_info: Optional[ArtistTitleInfo]
    artist_mbid: Optional[str]
    album_mbid: Optional[str]
    release_mbid: Optional[str]
    recording_mbid: Optional[str]
    track_mbid: Optional[str]
    disc_number: Optional[int]
    disc_count: Optional[int]
    country: Optional[IsoCountry]
    year: Optional[int]
    label: Optional[str]
    catalog_number: Optional[str]
    disambiguation: Optional[str]
    duration: Optional[str]
    quality: Optional[QualityModel]
    media_info: Optional[MediaInfoModel]
    track_numbers: Optional[List]
    release_group: Optional[str]
    release_hash: Optional[str]
    __properties = ["title", "cleanTitle", "artistTitle", "albumTitle", "artistTitleInfo", "artistMBId", "albumMBId", "releaseMBId", "recordingMBId", "trackMBId", "discNumber", "discCount", "country", "year", "label", "catalogNumber", "disambiguation", "duration", "quality", "mediaInfo", "trackNumbers", "releaseGroup", "releaseHash"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParsedTrackInfo:
        """Create an instance of ParsedTrackInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of artist_title_info
        if self.artist_title_info:
            _dict['artistTitleInfo'] = self.artist_title_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of country
        if self.country:
            _dict['country'] = self.country.to_dict()
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # override the default output from pydantic by calling `to_dict()` of media_info
        if self.media_info:
            _dict['mediaInfo'] = self.media_info.to_dict()
        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if clean_title (nullable) is None
        if self.clean_title is None:
            _dict['cleanTitle'] = None

        # set to None if artist_title (nullable) is None
        if self.artist_title is None:
            _dict['artistTitle'] = None

        # set to None if album_title (nullable) is None
        if self.album_title is None:
            _dict['albumTitle'] = None

        # set to None if artist_mbid (nullable) is None
        if self.artist_mbid is None:
            _dict['artistMBId'] = None

        # set to None if album_mbid (nullable) is None
        if self.album_mbid is None:
            _dict['albumMBId'] = None

        # set to None if release_mbid (nullable) is None
        if self.release_mbid is None:
            _dict['releaseMBId'] = None

        # set to None if recording_mbid (nullable) is None
        if self.recording_mbid is None:
            _dict['recordingMBId'] = None

        # set to None if track_mbid (nullable) is None
        if self.track_mbid is None:
            _dict['trackMBId'] = None

        # set to None if label (nullable) is None
        if self.label is None:
            _dict['label'] = None

        # set to None if catalog_number (nullable) is None
        if self.catalog_number is None:
            _dict['catalogNumber'] = None

        # set to None if disambiguation (nullable) is None
        if self.disambiguation is None:
            _dict['disambiguation'] = None

        # set to None if track_numbers (nullable) is None
        if self.track_numbers is None:
            _dict['trackNumbers'] = None

        # set to None if release_group (nullable) is None
        if self.release_group is None:
            _dict['releaseGroup'] = None

        # set to None if release_hash (nullable) is None
        if self.release_hash is None:
            _dict['releaseHash'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParsedTrackInfo:
        """Create an instance of ParsedTrackInfo from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ParsedTrackInfo.parse_obj(obj)

        _obj = ParsedTrackInfo.parse_obj({
            "title": obj.get("title"),
            "clean_title": obj.get("cleanTitle"),
            "artist_title": obj.get("artistTitle"),
            "album_title": obj.get("albumTitle"),
            "artist_title_info": ArtistTitleInfo.from_dict(obj.get("artistTitleInfo")) if obj.get("artistTitleInfo") is not None else None,
            "artist_mbid": obj.get("artistMBId"),
            "album_mbid": obj.get("albumMBId"),
            "release_mbid": obj.get("releaseMBId"),
            "recording_mbid": obj.get("recordingMBId"),
            "track_mbid": obj.get("trackMBId"),
            "disc_number": obj.get("discNumber"),
            "disc_count": obj.get("discCount"),
            "country": IsoCountry.from_dict(obj.get("country")) if obj.get("country") is not None else None,
            "year": obj.get("year"),
            "label": obj.get("label"),
            "catalog_number": obj.get("catalogNumber"),
            "disambiguation": obj.get("disambiguation"),
            "duration": obj.get("duration"),
            "quality": QualityModel.from_dict(obj.get("quality")) if obj.get("quality") is not None else None,
            "media_info": MediaInfoModel.from_dict(obj.get("mediaInfo")) if obj.get("mediaInfo") is not None else None,
            "track_numbers": obj.get("trackNumbers"),
            "release_group": obj.get("releaseGroup"),
            "release_hash": obj.get("releaseHash")
        })
        return _obj




# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class MonitorTypes(str, Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """

    ALL = 'all'
    FUTURE = 'future'
    MISSING = 'missing'
    EXISTING = 'existing'
    LATEST = 'latest'
    FIRST = 'first'
    NONE = 'none'
    UNKNOWN = 'unknown'




# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from lidarr.models.add_artist_options import AddArtistOptions
from lidarr.models.artist_metadata_lazy_loaded import ArtistMetadataLazyLoaded
from lidarr.models.metadata_profile_lazy_loaded import MetadataProfileLazyLoaded
from lidarr.models.new_item_monitor_types import NewItemMonitorTypes
from lidarr.models.quality_profile_lazy_loaded import QualityProfileLazyLoaded

class Artist(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    artist_metadata_id: Optional[int]
    clean_name: Optional[str]
    sort_name: Optional[str]
    monitored: Optional[bool]
    monitor_new_items: Optional[NewItemMonitorTypes]
    last_info_sync: Optional[datetime]
    path: Optional[str]
    root_folder_path: Optional[str]
    added: Optional[datetime]
    quality_profile_id: Optional[int]
    metadata_profile_id: Optional[int]
    tags: Optional[List]
    add_options: Optional[AddArtistOptions]
    metadata: Optional[ArtistMetadataLazyLoaded]
    quality_profile: Optional[QualityProfileLazyLoaded]
    metadata_profile: Optional[MetadataProfileLazyLoaded]
    albums: Optional[AlbumListLazyLoaded]
    name: Optional[str]
    foreign_artist_id: Optional[str]
    __properties = ["id", "artistMetadataId", "cleanName", "sortName", "monitored", "monitorNewItems", "lastInfoSync", "path", "rootFolderPath", "added", "qualityProfileId", "metadataProfileId", "tags", "addOptions", "metadata", "qualityProfile", "metadataProfile", "albums", "name", "foreignArtistId"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Artist:
        """Create an instance of Artist from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of add_options
        if self.add_options:
            _dict['addOptions'] = self.add_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of quality_profile
        if self.quality_profile:
            _dict['qualityProfile'] = self.quality_profile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metadata_profile
        if self.metadata_profile:
            _dict['metadataProfile'] = self.metadata_profile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of albums
        if self.albums:
            _dict['albums'] = self.albums.to_dict()
        # set to None if clean_name (nullable) is None
        if self.clean_name is None:
            _dict['cleanName'] = None

        # set to None if sort_name (nullable) is None
        if self.sort_name is None:
            _dict['sortName'] = None

        # set to None if last_info_sync (nullable) is None
        if self.last_info_sync is None:
            _dict['lastInfoSync'] = None

        # set to None if path (nullable) is None
        if self.path is None:
            _dict['path'] = None

        # set to None if root_folder_path (nullable) is None
        if self.root_folder_path is None:
            _dict['rootFolderPath'] = None

        # set to None if tags (nullable) is None
        if self.tags is None:
            _dict['tags'] = None

        # set to None if name (nullable) is None
        if self.name is None:
            _dict['name'] = None

        # set to None if foreign_artist_id (nullable) is None
        if self.foreign_artist_id is None:
            _dict['foreignArtistId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Artist:
        """Create an instance of Artist from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Artist.parse_obj(obj)

        _obj = Artist.parse_obj({
            "id": obj.get("id"),
            "artist_metadata_id": obj.get("artistMetadataId"),
            "clean_name": obj.get("cleanName"),
            "sort_name": obj.get("sortName"),
            "monitored": obj.get("monitored"),
            "monitor_new_items": obj.get("monitorNewItems"),
            "last_info_sync": obj.get("lastInfoSync"),
            "path": obj.get("path"),
            "root_folder_path": obj.get("rootFolderPath"),
            "added": obj.get("added"),
            "quality_profile_id": obj.get("qualityProfileId"),
            "metadata_profile_id": obj.get("metadataProfileId"),
            "tags": obj.get("tags"),
            "add_options": AddArtistOptions.from_dict(obj.get("addOptions")) if obj.get("addOptions") is not None else None,
            "metadata": ArtistMetadataLazyLoaded.from_dict(obj.get("metadata")) if obj.get("metadata") is not None else None,
            "quality_profile": QualityProfileLazyLoaded.from_dict(obj.get("qualityProfile")) if obj.get("qualityProfile") is not None else None,
            "metadata_profile": MetadataProfileLazyLoaded.from_dict(obj.get("metadataProfile")) if obj.get("metadataProfile") is not None else None,
            "albums": AlbumListLazyLoaded.from_dict(obj.get("albums")) if obj.get("albums") is not None else None,
            "name": obj.get("name"),
            "foreign_artist_id": obj.get("foreignArtistId")
        })
        return _obj




# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from lidarr.models.artist_metadata_lazy_loaded import ArtistMetadataLazyLoaded
from lidarr.models.ratings import Ratings

class Track(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    foreign_track_id: Optional[str]
    old_foreign_track_ids: Optional[List]
    foreign_recording_id: Optional[str]
    old_foreign_recording_ids: Optional[List]
    album_release_id: Optional[int]
    artist_metadata_id: Optional[int]
    track_number: Optional[str]
    absolute_track_number: Optional[int]
    title: Optional[str]
    duration: Optional[int]
    explicit: Optional[bool]
    ratings: Optional[Ratings]
    medium_number: Optional[int]
    track_file_id: Optional[int]
    has_file: Optional[bool]
    album_release: Optional[AlbumReleaseLazyLoaded]
    artist_metadata: Optional[ArtistMetadataLazyLoaded]
    track_file: Optional[TrackFileLazyLoaded]
    artist: Optional[ArtistLazyLoaded]
    album_id: Optional[int]
    album: Optional[Album]
    __properties = ["id", "foreignTrackId", "oldForeignTrackIds", "foreignRecordingId", "oldForeignRecordingIds", "albumReleaseId", "artistMetadataId", "trackNumber", "absoluteTrackNumber", "title", "duration", "explicit", "ratings", "mediumNumber", "trackFileId", "hasFile", "albumRelease", "artistMetadata", "trackFile", "artist", "albumId", "album"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Track:
        """Create an instance of Track from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "has_file",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of ratings
        if self.ratings:
            _dict['ratings'] = self.ratings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of album_release
        if self.album_release:
            _dict['albumRelease'] = self.album_release.to_dict()
        # override the default output from pydantic by calling `to_dict()` of artist_metadata
        if self.artist_metadata:
            _dict['artistMetadata'] = self.artist_metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of track_file
        if self.track_file:
            _dict['trackFile'] = self.track_file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of artist
        if self.artist:
            _dict['artist'] = self.artist.to_dict()
        # override the default output from pydantic by calling `to_dict()` of album
        if self.album:
            _dict['album'] = self.album.to_dict()
        # set to None if foreign_track_id (nullable) is None
        if self.foreign_track_id is None:
            _dict['foreignTrackId'] = None

        # set to None if old_foreign_track_ids (nullable) is None
        if self.old_foreign_track_ids is None:
            _dict['oldForeignTrackIds'] = None

        # set to None if foreign_recording_id (nullable) is None
        if self.foreign_recording_id is None:
            _dict['foreignRecordingId'] = None

        # set to None if old_foreign_recording_ids (nullable) is None
        if self.old_foreign_recording_ids is None:
            _dict['oldForeignRecordingIds'] = None

        # set to None if track_number (nullable) is None
        if self.track_number is None:
            _dict['trackNumber'] = None

        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Track:
        """Create an instance of Track from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Track.parse_obj(obj)

        _obj = Track.parse_obj({
            "id": obj.get("id"),
            "foreign_track_id": obj.get("foreignTrackId"),
            "old_foreign_track_ids": obj.get("oldForeignTrackIds"),
            "foreign_recording_id": obj.get("foreignRecordingId"),
            "old_foreign_recording_ids": obj.get("oldForeignRecordingIds"),
            "album_release_id": obj.get("albumReleaseId"),
            "artist_metadata_id": obj.get("artistMetadataId"),
            "track_number": obj.get("trackNumber"),
            "absolute_track_number": obj.get("absoluteTrackNumber"),
            "title": obj.get("title"),
            "duration": obj.get("duration"),
            "explicit": obj.get("explicit"),
            "ratings": Ratings.from_dict(obj.get("ratings")) if obj.get("ratings") is not None else None,
            "medium_number": obj.get("mediumNumber"),
            "track_file_id": obj.get("trackFileId"),
            "has_file": obj.get("hasFile"),
            "album_release": AlbumReleaseLazyLoaded.from_dict(obj.get("albumRelease")) if obj.get("albumRelease") is not None else None,
            "artist_metadata": ArtistMetadataLazyLoaded.from_dict(obj.get("artistMetadata")) if obj.get("artistMetadata") is not None else None,
            "track_file": TrackFileLazyLoaded.from_dict(obj.get("trackFile")) if obj.get("trackFile") is not None else None,
            "artist": ArtistLazyLoaded.from_dict(obj.get("artist")) if obj.get("artist") is not None else None,
            "album_id": obj.get("albumId"),
            "album": Album.from_dict(obj.get("album")) if obj.get("album") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from lidarr.models.add_artist_options import AddArtistOptions
from lidarr.models.album import Album
from lidarr.models.artist_statistics_resource import ArtistStatisticsResource
from lidarr.models.artist_status_type import ArtistStatusType
from lidarr.models.links import Links
from lidarr.models.media_cover import MediaCover
from lidarr.models.member import Member
from lidarr.models.new_item_monitor_types import NewItemMonitorTypes
from lidarr.models.ratings import Ratings

class ArtistResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    artist_metadata_id: Optional[int]
    status: Optional[ArtistStatusType]
    ended: Optional[bool]
    artist_name: Optional[str]
    foreign_artist_id: Optional[str]
    mb_id: Optional[str]
    tadb_id: Optional[int]
    discogs_id: Optional[int]
    all_music_id: Optional[str]
    overview: Optional[str]
    artist_type: Optional[str]
    disambiguation: Optional[str]
    links: Optional[List]
    next_album: Optional[Album]
    last_album: Optional[Album]
    images: Optional[List]
    members: Optional[List]
    remote_poster: Optional[str]
    path: Optional[str]
    quality_profile_id: Optional[int]
    metadata_profile_id: Optional[int]
    monitored: Optional[bool]
    monitor_new_items: Optional[NewItemMonitorTypes]
    root_folder_path: Optional[str]
    genres: Optional[List]
    clean_name: Optional[str]
    sort_name: Optional[str]
    tags: Optional[List]
    added: Optional[datetime]
    add_options: Optional[AddArtistOptions]
    ratings: Optional[Ratings]
    statistics: Optional[ArtistStatisticsResource]
    __properties = ["id", "artistMetadataId", "status", "ended", "artistName", "foreignArtistId", "mbId", "tadbId", "discogsId", "allMusicId", "overview", "artistType", "disambiguation", "links", "nextAlbum", "lastAlbum", "images", "members", "remotePoster", "path", "qualityProfileId", "metadataProfileId", "monitored", "monitorNewItems", "rootFolderPath", "genres", "cleanName", "sortName", "tags", "added", "addOptions", "ratings", "statistics"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ArtistResource:
        """Create an instance of ArtistResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "ended",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item in self.links:
                if _item:
                    _items.append(_item.to_dict())
            _dict['links'] = _items
        # override the default output from pydantic by calling `to_dict()` of next_album
        if self.next_album:
            _dict['nextAlbum'] = self.next_album.to_dict()
        # override the default output from pydantic by calling `to_dict()` of last_album
        if self.last_album:
            _dict['lastAlbum'] = self.last_album.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item in self.images:
                if _item:
                    _items.append(_item.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in members (list)
        _items = []
        if self.members:
            for _item in self.members:
                if _item:
                    _items.append(_item.to_dict())
            _dict['members'] = _items
        # override the default output from pydantic by calling `to_dict()` of add_options
        if self.add_options:
            _dict['addOptions'] = self.add_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ratings
        if self.ratings:
            _dict['ratings'] = self.ratings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of statistics
        if self.statistics:
            _dict['statistics'] = self.statistics.to_dict()
        # set to None if artist_name (nullable) is None
        if self.artist_name is None:
            _dict['artistName'] = None

        # set to None if foreign_artist_id (nullable) is None
        if self.foreign_artist_id is None:
            _dict['foreignArtistId'] = None

        # set to None if mb_id (nullable) is None
        if self.mb_id is None:
            _dict['mbId'] = None

        # set to None if all_music_id (nullable) is None
        if self.all_music_id is None:
            _dict['allMusicId'] = None

        # set to None if overview (nullable) is None
        if self.overview is None:
            _dict['overview'] = None

        # set to None if artist_type (nullable) is None
        if self.artist_type is None:
            _dict['artistType'] = None

        # set to None if disambiguation (nullable) is None
        if self.disambiguation is None:
            _dict['disambiguation'] = None

        # set to None if links (nullable) is None
        if self.links is None:
            _dict['links'] = None

        # set to None if images (nullable) is None
        if self.images is None:
            _dict['images'] = None

        # set to None if members (nullable) is None
        if self.members is None:
            _dict['members'] = None

        # set to None if remote_poster (nullable) is None
        if self.remote_poster is None:
            _dict['remotePoster'] = None

        # set to None if path (nullable) is None
        if self.path is None:
            _dict['path'] = None

        # set to None if root_folder_path (nullable) is None
        if self.root_folder_path is None:
            _dict['rootFolderPath'] = None

        # set to None if genres (nullable) is None
        if self.genres is None:
            _dict['genres'] = None

        # set to None if clean_name (nullable) is None
        if self.clean_name is None:
            _dict['cleanName'] = None

        # set to None if sort_name (nullable) is None
        if self.sort_name is None:
            _dict['sortName'] = None

        # set to None if tags (nullable) is None
        if self.tags is None:
            _dict['tags'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ArtistResource:
        """Create an instance of ArtistResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ArtistResource.parse_obj(obj)

        _obj = ArtistResource.parse_obj({
            "id": obj.get("id"),
            "artist_metadata_id": obj.get("artistMetadataId"),
            "status": obj.get("status"),
            "ended": obj.get("ended"),
            "artist_name": obj.get("artistName"),
            "foreign_artist_id": obj.get("foreignArtistId"),
            "mb_id": obj.get("mbId"),
            "tadb_id": obj.get("tadbId"),
            "discogs_id": obj.get("discogsId"),
            "all_music_id": obj.get("allMusicId"),
            "overview": obj.get("overview"),
            "artist_type": obj.get("artistType"),
            "disambiguation": obj.get("disambiguation"),
            "links": [Links.from_dict(_item) for _item in obj.get("links")] if obj.get("links") is not None else None,
            "next_album": Album.from_dict(obj.get("nextAlbum")) if obj.get("nextAlbum") is not None else None,
            "last_album": Album.from_dict(obj.get("lastAlbum")) if obj.get("lastAlbum") is not None else None,
            "images": [MediaCover.from_dict(_item) for _item in obj.get("images")] if obj.get("images") is not None else None,
            "members": [Member.from_dict(_item) for _item in obj.get("members")] if obj.get("members") is not None else None,
            "remote_poster": obj.get("remotePoster"),
            "path": obj.get("path"),
            "quality_profile_id": obj.get("qualityProfileId"),
            "metadata_profile_id": obj.get("metadataProfileId"),
            "monitored": obj.get("monitored"),
            "monitor_new_items": obj.get("monitorNewItems"),
            "root_folder_path": obj.get("rootFolderPath"),
            "genres": obj.get("genres"),
            "clean_name": obj.get("cleanName"),
            "sort_name": obj.get("sortName"),
            "tags": obj.get("tags"),
            "added": obj.get("added"),
            "add_options": AddArtistOptions.from_dict(obj.get("addOptions")) if obj.get("addOptions") is not None else None,
            "ratings": Ratings.from_dict(obj.get("ratings")) if obj.get("ratings") is not None else None,
            "statistics": ArtistStatisticsResource.from_dict(obj.get("statistics")) if obj.get("statistics") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel

class ArtistStatisticsResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    album_count: Optional[int]
    track_file_count: Optional[int]
    track_count: Optional[int]
    total_track_count: Optional[int]
    size_on_disk: Optional[int]
    percent_of_tracks: Optional[float]
    __properties = ["albumCount", "trackFileCount", "trackCount", "totalTrackCount", "sizeOnDisk", "percentOfTracks"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ArtistStatisticsResource:
        """Create an instance of ArtistStatisticsResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "percent_of_tracks",
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ArtistStatisticsResource:
        """Create an instance of ArtistStatisticsResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ArtistStatisticsResource.parse_obj(obj)

        _obj = ArtistStatisticsResource.parse_obj({
            "album_count": obj.get("albumCount"),
            "track_file_count": obj.get("trackFileCount"),
            "track_count": obj.get("trackCount"),
            "total_track_count": obj.get("totalTrackCount"),
            "size_on_disk": obj.get("sizeOnDisk"),
            "percent_of_tracks": obj.get("percentOfTracks")
        })
        return _obj




# coding: utf-8

# flake8: noqa

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from lidarr.models.add_album_options import AddAlbumOptions
from lidarr.models.add_artist_options import AddArtistOptions
from lidarr.models.album import Album
from lidarr.models.album_add_type import AlbumAddType
from lidarr.models.album_lazy_loaded import AlbumLazyLoaded
from lidarr.models.album_list_lazy_loaded import AlbumListLazyLoaded
from lidarr.models.album_release import AlbumRelease
from lidarr.models.album_release_lazy_loaded import AlbumReleaseLazyLoaded
from lidarr.models.album_release_list_lazy_loaded import AlbumReleaseListLazyLoaded
from lidarr.models.album_release_resource import AlbumReleaseResource
from lidarr.models.album_resource import AlbumResource
from lidarr.models.album_resource_paging_resource import AlbumResourcePagingResource
from lidarr.models.album_statistics_resource import AlbumStatisticsResource
from lidarr.models.album_studio_artist_resource import AlbumStudioArtistResource
from lidarr.models.album_studio_resource import AlbumStudioResource
from lidarr.models.albums_monitored_resource import AlbumsMonitoredResource
from lidarr.models.allow_fingerprinting import AllowFingerprinting
from lidarr.models.apply_tags import ApplyTags
from lidarr.models.artist import Artist
from lidarr.models.artist_editor_resource import ArtistEditorResource
from lidarr.models.artist_lazy_loaded import ArtistLazyLoaded
from lidarr.models.artist_metadata import ArtistMetadata
from lidarr.models.artist_metadata_lazy_loaded import ArtistMetadataLazyLoaded
from lidarr.models.artist_resource import ArtistResource
from lidarr.models.artist_statistics_resource import ArtistStatisticsResource
from lidarr.models.artist_status_type import ArtistStatusType
from lidarr.models.artist_title_info import ArtistTitleInfo
from lidarr.models.authentication_type import AuthenticationType
from lidarr.models.backup_resource import BackupResource
from lidarr.models.backup_type import BackupType
from lidarr.models.blocklist_bulk_resource import BlocklistBulkResource
from lidarr.models.blocklist_resource import BlocklistResource
from lidarr.models.blocklist_resource_paging_resource import BlocklistResourcePagingResource
from lidarr.models.certificate_validation_type import CertificateValidationType
from lidarr.models.command import Command
from lidarr.models.command_priority import CommandPriority
from lidarr.models.command_resource import CommandResource
from lidarr.models.command_result import CommandResult
from lidarr.models.command_status import CommandStatus
from lidarr.models.command_trigger import CommandTrigger
from lidarr.models.custom_filter_resource import CustomFilterResource
from lidarr.models.custom_format import CustomFormat
from lidarr.models.custom_format_resource import CustomFormatResource
from lidarr.models.custom_format_specification_schema import CustomFormatSpecificationSchema
from lidarr.models.database_type import DatabaseType
from lidarr.models.delay_profile_resource import DelayProfileResource
from lidarr.models.disk_space_resource import DiskSpaceResource
from lidarr.models.download_client_bulk_resource import DownloadClientBulkResource
from lidarr.models.download_client_config_resource import DownloadClientConfigResource
from lidarr.models.download_client_resource import DownloadClientResource
from lidarr.models.download_protocol import DownloadProtocol
from lidarr.models.entity_history_event_type import EntityHistoryEventType
from lidarr.models.field import Field
from lidarr.models.file_date_type import FileDateType
from lidarr.models.health_check_result import HealthCheckResult
from lidarr.models.health_resource import HealthResource
from lidarr.models.history_resource import HistoryResource
from lidarr.models.history_resource_paging_resource import HistoryResourcePagingResource
from lidarr.models.host_config_resource import HostConfigResource
from lidarr.models.i_custom_format_specification import ICustomFormatSpecification
from lidarr.models.import_list_bulk_resource import ImportListBulkResource
from lidarr.models.import_list_exclusion_resource import ImportListExclusionResource
from lidarr.models.import_list_monitor_type import ImportListMonitorType
from lidarr.models.import_list_resource import ImportListResource
from lidarr.models.import_list_type import ImportListType
from lidarr.models.indexer_bulk_resource import IndexerBulkResource
from lidarr.models.indexer_config_resource import IndexerConfigResource
from lidarr.models.indexer_resource import IndexerResource
from lidarr.models.iso_country import IsoCountry
from lidarr.models.language_resource import LanguageResource
from lidarr.models.links import Links
from lidarr.models.localization_resource import LocalizationResource
from lidarr.models.log_file_resource import LogFileResource
from lidarr.models.log_resource import LogResource
from lidarr.models.log_resource_paging_resource import LogResourcePagingResource
from lidarr.models.manual_import_resource import ManualImportResource
from lidarr.models.manual_import_update_resource import ManualImportUpdateResource
from lidarr.models.media_cover import MediaCover
from lidarr.models.media_cover_types import MediaCoverTypes
from lidarr.models.media_info_model import MediaInfoModel
from lidarr.models.media_info_resource import MediaInfoResource
from lidarr.models.media_management_config_resource import MediaManagementConfigResource
from lidarr.models.medium import Medium
from lidarr.models.medium_resource import MediumResource
from lidarr.models.member import Member
from lidarr.models.metadata_profile import MetadataProfile
from lidarr.models.metadata_profile_lazy_loaded import MetadataProfileLazyLoaded
from lidarr.models.metadata_profile_resource import MetadataProfileResource
from lidarr.models.metadata_provider_config_resource import MetadataProviderConfigResource
from lidarr.models.metadata_resource import MetadataResource
from lidarr.models.monitor_types import MonitorTypes
from lidarr.models.monitoring_options import MonitoringOptions
from lidarr.models.naming_config_resource import NamingConfigResource
from lidarr.models.new_item_monitor_types import NewItemMonitorTypes
from lidarr.models.notification_resource import NotificationResource
from lidarr.models.paging_resource_filter import PagingResourceFilter
from lidarr.models.parse_resource import ParseResource
from lidarr.models.parsed_album_info import ParsedAlbumInfo
from lidarr.models.parsed_track_info import ParsedTrackInfo
from lidarr.models.ping_resource import PingResource
from lidarr.models.primary_album_type import PrimaryAlbumType
from lidarr.models.profile_format_item import ProfileFormatItem
from lidarr.models.profile_format_item_resource import ProfileFormatItemResource
from lidarr.models.profile_primary_album_type_item import ProfilePrimaryAlbumTypeItem
from lidarr.models.profile_primary_album_type_item_resource import ProfilePrimaryAlbumTypeItemResource
from lidarr.models.profile_release_status_item import ProfileReleaseStatusItem
from lidarr.models.profile_release_status_item_resource import ProfileReleaseStatusItemResource
from lidarr.models.profile_secondary_album_type_item import ProfileSecondaryAlbumTypeItem
from lidarr.models.profile_secondary_album_type_item_resource import ProfileSecondaryAlbumTypeItemResource
from lidarr.models.proper_download_types import ProperDownloadTypes
from lidarr.models.provider_message import ProviderMessage
from lidarr.models.provider_message_type import ProviderMessageType
from lidarr.models.proxy_type import ProxyType
from lidarr.models.quality import Quality
from lidarr.models.quality_definition_resource import QualityDefinitionResource
from lidarr.models.quality_model import QualityModel
from lidarr.models.quality_profile import QualityProfile
from lidarr.models.quality_profile_lazy_loaded import QualityProfileLazyLoaded
from lidarr.models.quality_profile_quality_item import QualityProfileQualityItem
from lidarr.models.quality_profile_quality_item_resource import QualityProfileQualityItemResource
from lidarr.models.quality_profile_resource import QualityProfileResource
from lidarr.models.queue_bulk_resource import QueueBulkResource
from lidarr.models.queue_resource import QueueResource
from lidarr.models.queue_resource_paging_resource import QueueResourcePagingResource
from lidarr.models.queue_status_resource import QueueStatusResource
from lidarr.models.ratings import Ratings
from lidarr.models.rejection import Rejection
from lidarr.models.rejection_type import RejectionType
from lidarr.models.release_profile_resource import ReleaseProfileResource
from lidarr.models.release_resource import ReleaseResource
from lidarr.models.release_status import ReleaseStatus
from lidarr.models.remote_path_mapping_resource import RemotePathMappingResource
from lidarr.models.rename_track_resource import RenameTrackResource
from lidarr.models.rescan_after_refresh_type import RescanAfterRefreshType
from lidarr.models.retag_track_resource import RetagTrackResource
from lidarr.models.revision import Revision
from lidarr.models.root_folder_resource import RootFolderResource
from lidarr.models.runtime_mode import RuntimeMode
from lidarr.models.secondary_album_type import SecondaryAlbumType
from lidarr.models.select_option import SelectOption
from lidarr.models.sort_direction import SortDirection
from lidarr.models.system_resource import SystemResource
from lidarr.models.tag_details_resource import TagDetailsResource
from lidarr.models.tag_difference import TagDifference
from lidarr.models.tag_resource import TagResource
from lidarr.models.task_resource import TaskResource
from lidarr.models.track import Track
from lidarr.models.track_file import TrackFile
from lidarr.models.track_file_lazy_loaded import TrackFileLazyLoaded
from lidarr.models.track_file_list_resource import TrackFileListResource
from lidarr.models.track_file_resource import TrackFileResource
from lidarr.models.track_list_lazy_loaded import TrackListLazyLoaded
from lidarr.models.track_resource import TrackResource
from lidarr.models.tracked_download_state import TrackedDownloadState
from lidarr.models.tracked_download_status import TrackedDownloadStatus
from lidarr.models.tracked_download_status_message import TrackedDownloadStatusMessage
from lidarr.models.ui_config_resource import UiConfigResource
from lidarr.models.update_changes import UpdateChanges
from lidarr.models.update_mechanism import UpdateMechanism
from lidarr.models.update_resource import UpdateResource
from lidarr.models.write_audio_tags_type import WriteAudioTagsType



# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from lidarr.models.artist_title_info import ArtistTitleInfo
from lidarr.models.quality_model import QualityModel

class ParsedAlbumInfo(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    album_title: Optional[str]
    artist_name: Optional[str]
    artist_title_info: Optional[ArtistTitleInfo]
    quality: Optional[QualityModel]
    release_date: Optional[str]
    discography: Optional[bool]
    discography_start: Optional[int]
    discography_end: Optional[int]
    release_group: Optional[str]
    release_hash: Optional[str]
    release_version: Optional[str]
    release_title: Optional[str]
    __properties = ["albumTitle", "artistName", "artistTitleInfo", "quality", "releaseDate", "discography", "discographyStart", "discographyEnd", "releaseGroup", "releaseHash", "releaseVersion", "releaseTitle"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParsedAlbumInfo:
        """Create an instance of ParsedAlbumInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of artist_title_info
        if self.artist_title_info:
            _dict['artistTitleInfo'] = self.artist_title_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # set to None if album_title (nullable) is None
        if self.album_title is None:
            _dict['albumTitle'] = None

        # set to None if artist_name (nullable) is None
        if self.artist_name is None:
            _dict['artistName'] = None

        # set to None if release_date (nullable) is None
        if self.release_date is None:
            _dict['releaseDate'] = None

        # set to None if release_group (nullable) is None
        if self.release_group is None:
            _dict['releaseGroup'] = None

        # set to None if release_hash (nullable) is None
        if self.release_hash is None:
            _dict['releaseHash'] = None

        # set to None if release_version (nullable) is None
        if self.release_version is None:
            _dict['releaseVersion'] = None

        # set to None if release_title (nullable) is None
        if self.release_title is None:
            _dict['releaseTitle'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParsedAlbumInfo:
        """Create an instance of ParsedAlbumInfo from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ParsedAlbumInfo.parse_obj(obj)

        _obj = ParsedAlbumInfo.parse_obj({
            "album_title": obj.get("albumTitle"),
            "artist_name": obj.get("artistName"),
            "artist_title_info": ArtistTitleInfo.from_dict(obj.get("artistTitleInfo")) if obj.get("artistTitleInfo") is not None else None,
            "quality": QualityModel.from_dict(obj.get("quality")) if obj.get("quality") is not None else None,
            "release_date": obj.get("releaseDate"),
            "discography": obj.get("discography"),
            "discography_start": obj.get("discographyStart"),
            "discography_end": obj.get("discographyEnd"),
            "release_group": obj.get("releaseGroup"),
            "release_hash": obj.get("releaseHash"),
            "release_version": obj.get("releaseVersion"),
            "release_title": obj.get("releaseTitle")
        })
        return _obj




# coding: utf-8

# flake8: noqa

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


# import apis into api package
from lidarr.api.album_api import AlbumApi
from lidarr.api.album_lookup_api import AlbumLookupApi
from lidarr.api.album_studio_api import AlbumStudioApi
from lidarr.api.api_info_api import ApiInfoApi
from lidarr.api.artist_api import ArtistApi
from lidarr.api.artist_editor_api import ArtistEditorApi
from lidarr.api.artist_lookup_api import ArtistLookupApi
from lidarr.api.authentication_api import AuthenticationApi
from lidarr.api.backup_api import BackupApi
from lidarr.api.blocklist_api import BlocklistApi
from lidarr.api.calendar_api import CalendarApi
from lidarr.api.calendar_feed_api import CalendarFeedApi
from lidarr.api.command_api import CommandApi
from lidarr.api.custom_filter_api import CustomFilterApi
from lidarr.api.custom_format_api import CustomFormatApi
from lidarr.api.cutoff_api import CutoffApi
from lidarr.api.delay_profile_api import DelayProfileApi
from lidarr.api.disk_space_api import DiskSpaceApi
from lidarr.api.download_client_api import DownloadClientApi
from lidarr.api.download_client_config_api import DownloadClientConfigApi
from lidarr.api.file_system_api import FileSystemApi
from lidarr.api.health_api import HealthApi
from lidarr.api.history_api import HistoryApi
from lidarr.api.host_config_api import HostConfigApi
from lidarr.api.import_list_api import ImportListApi
from lidarr.api.import_list_exclusion_api import ImportListExclusionApi
from lidarr.api.indexer_api import IndexerApi
from lidarr.api.indexer_config_api import IndexerConfigApi
from lidarr.api.initialize_js_api import InitializeJsApi
from lidarr.api.language_api import LanguageApi
from lidarr.api.localization_api import LocalizationApi
from lidarr.api.log_api import LogApi
from lidarr.api.log_file_api import LogFileApi
from lidarr.api.manual_import_api import ManualImportApi
from lidarr.api.media_cover_api import MediaCoverApi
from lidarr.api.media_management_config_api import MediaManagementConfigApi
from lidarr.api.metadata_api import MetadataApi
from lidarr.api.metadata_profile_api import MetadataProfileApi
from lidarr.api.metadata_profile_schema_api import MetadataProfileSchemaApi
from lidarr.api.metadata_provider_config_api import MetadataProviderConfigApi
from lidarr.api.missing_api import MissingApi
from lidarr.api.naming_config_api import NamingConfigApi
from lidarr.api.notification_api import NotificationApi
from lidarr.api.parse_api import ParseApi
from lidarr.api.ping_api import PingApi
from lidarr.api.quality_definition_api import QualityDefinitionApi
from lidarr.api.quality_profile_api import QualityProfileApi
from lidarr.api.quality_profile_schema_api import QualityProfileSchemaApi
from lidarr.api.queue_api import QueueApi
from lidarr.api.queue_action_api import QueueActionApi
from lidarr.api.queue_details_api import QueueDetailsApi
from lidarr.api.queue_status_api import QueueStatusApi
from lidarr.api.release_api import ReleaseApi
from lidarr.api.release_profile_api import ReleaseProfileApi
from lidarr.api.release_push_api import ReleasePushApi
from lidarr.api.remote_path_mapping_api import RemotePathMappingApi
from lidarr.api.rename_track_api import RenameTrackApi
from lidarr.api.retag_track_api import RetagTrackApi
from lidarr.api.root_folder_api import RootFolderApi
from lidarr.api.search_api import SearchApi
from lidarr.api.static_resource_api import StaticResourceApi
from lidarr.api.system_api import SystemApi
from lidarr.api.tag_api import TagApi
from lidarr.api.tag_details_api import TagDetailsApi
from lidarr.api.task_api import TaskApi
from lidarr.api.track_api import TrackApi
from lidarr.api.track_file_api import TrackFileApi
from lidarr.api.ui_config_api import UiConfigApi
from lidarr.api.update_api import UpdateApi
from lidarr.api.update_log_file_api import UpdateLogFileApi



# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel
from lidarr.models.backup_type import BackupType

class BackupResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    name: Optional[str]
    path: Optional[str]
    type: Optional[BackupType]
    size: Optional[int]
    time: Optional[datetime]
    __properties = ["id", "name", "path", "type", "size", "time"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BackupResource:
        """Create an instance of BackupResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if name (nullable) is None
        if self.name is None:
            _dict['name'] = None

        # set to None if path (nullable) is None
        if self.path is None:
            _dict['path'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BackupResource:
        """Create an instance of BackupResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BackupResource.parse_obj(obj)

        _obj = BackupResource.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "path": obj.get("path"),
            "type": obj.get("type"),
            "size": obj.get("size"),
            "time": obj.get("time")
        })
        return _obj




# coding: utf-8

"""
    Lidarr

    Lidarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from lidarr.models.profile_primary_album_type_item import ProfilePrimaryAlbumTypeItem
from lidarr.models.profile_release_status_item import ProfileReleaseStatusItem
from lidarr.models.profile_secondary_album_type_item import ProfileSecondaryAlbumTypeItem

class MetadataProfile(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    name: Optional[str]
    primary_album_types: Optional[List]
    secondary_album_types: Optional[List]
    release_statuses: Optional[List]
    __properties = ["id", "name", "primaryAlbumTypes", "secondaryAlbumTypes", "releaseStatuses"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MetadataProfile:
        """Create an instance of MetadataProfile from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in primary_album_types (list)
        _items = []
        if self.primary_album_types:
            for _item in self.primary_album_types:
                if _item:
                    _items.append(_item.to_dict())
            _dict['primaryAlbumTypes'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in secondary_album_types (list)
        _items = []
        if self.secondary_album_types:
            for _item in self.secondary_album_types:
                if _item:
                    _items.append(_item.to_dict())
            _dict['secondaryAlbumTypes'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in release_statuses (list)
        _items = []
        if self.release_statuses:
            for _item in self.release_statuses:
                if _item:
                    _items.append(_item.to_dict())
            _dict['releaseStatuses'] = _items
        # set to None if name (nullable) is None
        if self.name is None:
            _dict['name'] = None

        # set to None if primary_album_types (nullable) is None
        if self.primary_album_types is None:
            _dict['primaryAlbumTypes'] = None

        # set to None if secondary_album_types (nullable) is None
        if self.secondary_album_types is None:
            _dict['secondaryAlbumTypes'] = None

        # set to None if release_statuses (nullable) is None
        if self.release_statuses is None:
            _dict['releaseStatuses'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MetadataProfile:
        """Create an instance of MetadataProfile from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return MetadataProfile.parse_obj(obj)

        _obj = MetadataProfile.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "primary_album_types": [ProfilePrimaryAlbumTypeItem.from_dict(_item) for _item in obj.get("primaryAlbumTypes")] if obj.get("primaryAlbumTypes") is not None else None,
            "secondary_album_types": [ProfileSecondaryAlbumTypeItem.from_dict(_item) for _item in obj.get("secondaryAlbumTypes")] if obj.get("secondaryAlbumTypes") is not None else None,
            "release_statuses": [ProfileReleaseStatusItem.from_dict(_item) for _item in obj.get("releaseStatuses")] if obj.get("releaseStatuses") is not None else None
        })
        return _obj

